icsemantic.catalog.criteria

Package platecom :: Package ontocatalog :: Package criteria |
[hide private]
[frames] | no frames]

# Package criteria

source code

In this module defines three criteria content types for ATTopic to match the catalog indexes defined in the 'indexes' module.

Submodules | [hide private]
icsemantic.catalog.criteria.related: A friendly criterion for ATTopic that matches the SearchableRelatedText index parameters icsemantic.catalog.criteria.synonym: A friendly criterion for ATTopic that matches the SearchableSynonymousText index parameters. icsemantic.catalog.criteria.translation: A friendly criterion for ATTopic that matches the SearchableTranslatedText index parameters.